PyQuant
-------
[![Build Status](https://github.com/chris7/pyquant/workflows/Build-and-Test/badge.svg)](https://github.com/chris7/pyquant/actions)

PyQuant is a versatile tool for analysis of mass spectrometry data.

More information can be found on the [github pages](https://chris7.github.io/pyquant/).

To read about the algorithm and examples, see the PyQuant publication:

https://www.ncbi.nlm.nih.gov/pubmed/27231314
